@@ -7,7 +7,7 @@ class ClientConfig:
     """Global options for a local client"""
 
     # default URL of Racetrack API server (Lifecycle URL)
-    lifecycle_url: str = 'http://127.0.0.1:7002'
+    lifecycle_url: str = 'http://localhost:7002'
 
     # Git auth credentials set for particular repositories
     git_credentials: Dict[str, 'Credentials'] = field(default_factory=dict)
@@ -15,6 +15,9 @@ class ClientConfig:
     # Racetrack URL aliases: alias name -> full URL to Lifecycle API
     lifecycle_url_aliases: Dict[str, str] = field(default_factory=dict)
 
+    # User auth is base64 encoded json with username/token, per Lifecycle URL
+    user_auths: Dict[str, str] = field(default_factory=dict)
+
 
 @dataclass
 class Credentials:
