@@ -1,4 +1,3 @@
-import logging
 from pathlib import Path
 from typing import Dict, Optional
 
@@ -6,6 +5,9 @@ import yaml
 from racetrack_client.log.context_error import wrap_context
 from racetrack_client.manifest.manifest import Manifest
 from racetrack_client.utils.dataclass import parse_dict_dataclass, parse_yaml_dataclass
+from racetrack_client.log.logs import get_logger
+
+logger = get_logger(__name__)
 
 FATMAN_MANIFEST_FILENAME = 'fatman.yaml'
 
@@ -35,5 +37,5 @@ def parse_manifest_or_empty(manifest_yaml: Optional[str]) -> Optional[Manifest]:
     try:
         return parse_yaml_dataclass(manifest_yaml, Manifest)
     except Exception as e:
-        logging.error(f'Fatman Manifest YAML contains syntax error: {e}')
+        logger.error(f'Fatman Manifest YAML contains syntax error: {e}')
         return None
