@@ -1,4 +1,3 @@
-import logging
 import os
 from pathlib import Path
 from typing import List, Type, TypeVar
@@ -6,8 +5,12 @@ from typing import List, Type, TypeVar
 import dacite
 import yaml
 
+from racetrack_client.log.logs import get_logger
+
 T = TypeVar("T")
 
+logger = get_logger(__name__)
+
 
 def load_config(clazz: Type[T], cast_types: List[Type] = None) -> T:
     """
@@ -18,7 +21,7 @@ def load_config(clazz: Type[T], cast_types: List[Type] = None) -> T:
     """
     config_file_path = os.environ.get('CONFIG_FILE')
     if not config_file_path:
-        logging.warning('CONFIG_FILE unspecified, loading default config')
+        logger.warning('CONFIG_FILE unspecified, loading default config')
         return clazz()
 
     path = Path(config_file_path)
@@ -34,7 +37,7 @@ def load_config(clazz: Type[T], cast_types: List[Type] = None) -> T:
                 config=dacite.Config(cast=cast_types or []),
             )
 
-            logging.info(f'config loaded from {config_file_path}: {config}')
+            logger.info(f'config loaded from {config_file_path}: {config}')
             return config
     except Exception as e:
         raise RuntimeError('loading config failed') from e
